@@ -9,6 +9,6 @@
 alfadist <- function(x, a, type = "euclidean", square = FALSE) {
   ## x contains the compositional data
   ## a is the power parameter, usually between -1 and 1
-  y <- alfa(x, a, h = TRUE)$aff
+  y <- alfa(x, a, h = FALSE)$aff
   Rfast::Dist(y, method = type, square = square)
 }
